@@ -237,36 +237,43 @@ def push_csv2tog(job_id: int, file_path: str, access_token: str):
     """
     data_frame = pd.read_csv(file_path)
     dataset = []
-    expected_columns = ["call_uuid", "conversation_uuid", "alternatives", 
-        "audio_url", "reftime", "prediction", "state", "ack_slots", "end_state", 
-        "call_duration", "state_transitions"]
 
     for _, row in tqdm(data_frame.iterrows(), total=len(data_frame)):
-        safe_row = {col: row[col] if not pd.isna(row[col]) else json.dumps([]) for col in data_frame.columns}
+        if "raw" in data_frame.columns:
+            dataset.append({
+                "priority": 1,
+                "data_source": "fsm",
+                "data_id": row["data_id"],
+                "data": json.loads(row["raw"]),
+                "is_gold": False
+            })
+        else:
+            safe_row = {col: row[col] if not pd.isna(row[col]) else json.dumps([]) for col in data_frame.columns}
+            alternatives = json.loads(safe_row["alternatives"])
+            if alternatives and isinstance(alternatives, list) and isinstance(alternatives[0], dict):
+                alternatives = [alternatives]
+            if isinstance(alternatives, dict) and "alternatives" in alternatives:
+                alternatives = alternatives["alternatives"]
 
-        alternatives = json.loads(safe_row["alternatives"])
-        if alternatives and isinstance(alternatives, list) and isinstance(alternatives[0], dict):
-            alternatives = [alternatives]
- 
-        dataset.append({
-            "priority": 1,
-            "data_source": "fsm",
-            "data_id": safe_row["conversation_uuid"],
-            "data": {
-                "call_uuid": safe_row["call_uuid"],
-                "conversation_uuid": safe_row["conversation_uuid"],
-                "alternatives": alternatives,
-                "audio_url": safe_row["audio_url"],
-                "reftime": safe_row["reftime"],
-                "prediction": safe_row["prediction"],
-                "state": safe_row["state"],
-                "ack_slots": safe_row["ack_slots"],
-                "end_state": safe_row["end_state"],
-                "call_duration": safe_row["call_duration"],
-                "state_transitions": safe_row["state_transitions"]
-            },
-            "is_gold": False
-        })
+            dataset.append({
+                "priority": 1,
+                "data_source": "fsm",
+                "data_id": safe_row["conversation_uuid"],
+                "data": {
+                    "call_uuid": safe_row["call_uuid"],
+                    "conversation_uuid": safe_row["conversation_uuid"],
+                    "alternatives": alternatives,
+                    "audio_url": safe_row.get("audio_url"),
+                    "reftime": safe_row.get("reftime"),
+                    "prediction": safe_row.get("prediction"),
+                    "state": safe_row.get("state"),
+                    "ack_slots": safe_row.get("ack_slots"),
+                    "end_state": safe_row.get("end_state"),
+                    "call_duration": safe_row.get("call_duration"),
+                    "state_transitions": safe_row.get("state_transitions")
+                },
+                "is_gold": False
+            })
 
     dataset_chunks = chunk_list(dataset, chunks=20)
     return upload_data_v2(dataset_chunks, job_id, access_token)
